@@ -1,7 +1,13 @@
 use chess;
 
+#[macro_use]
+extern crate lazy_static;
+
 pub use chess::*;
 
+mod error;
+pub use crate::error::*;
+
 mod holdings;
 pub use crate::holdings::*;
 
